==> rivendell-2.0.0beta1.tar.gz: rivendell-2.0.0beta1/rdcastmanager/rdcastmanager_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-4.0.0beta1.tar.gz: rivendell-4.0.0beta1/rdcastmanager/rdcastmanager_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>EditCast</name>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item contains explicit content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editing Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posted By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item expiration cannot be prior to Air Date/Time!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item expiration must be in the future!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast Item List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting Item...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to drop remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to update remote XML data!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Audio File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogDialog</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At least one log event must be selected!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List Log Events</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>User: [Unknown]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy URL to
Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View
Feed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenderDialog</name>
    <message>
        <source>[now]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As Specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Treat as PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At STOP transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Render Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected Log Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>through</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
